@@ -47,11 +47,15 @@ QString Controller::getLanguage() const {
     QString german(tr("German"));
     QString italian(tr("Italian"));
     QString finnish(tr("Finnish"));
+    QString dutch(tr("Dutch"));
+    QString polish(tr("Polish"));
 
     langs[english] = "en";
     langs[german] = "de";
     langs[italian] = "it";
     langs[finnish] = "fi";
+    langs[dutch] = "nl";
+    langs[polish] = "pl";
 
     QString langCode = "en";
 
@@ -71,28 +75,10 @@ QString Controller::getLanguage() const {
         langCode = langs.value(language, "en");
     }
     //    qDebug() << langCode;
+    db.close();
     return langCode;
 }
 
-QStringList Controller::getDefaultAccountFromDB() const {
-    QSqlDatabase db;
-    db = QSqlDatabase::addDatabase("QSQLITE");
-    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
-    db.open();
-
-    QSqlQuery query("select username, password from accounts where isDefault = '1'");
-    QSqlRecord record = query.record();
-    QStringList account;
-    if (record.count() > 0) {
-        while (query.next()) {
-            account << query.value(0).toString();
-            account << query.value(1).toString();
-        }
-        //        qDebug() << account;
-    }
-    return account;
-}
-
 void Controller::setOrientation(const QString &orient) {
     if (orient == "Automatic") {
         m_view->setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
@@ -134,6 +120,7 @@ void Controller::getMediaPlayerFromDB() {
         //        qDebug() << player;
     }
     setMediaPlayer(player);
+    db.close();
 }
 
 QStringList Controller::getInstalledMediaPlayers() const {
@@ -174,11 +161,14 @@ void Controller::playVideo(const QString &url) {
     }
     emit playbackStarted();
 #endif
-//    QStringList args;
-//    args << "-cache" << "4096" << "-fs" << url;
-//    QProcess *player = new QProcess();
-//    connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
-//    player->start("/usr/bin/mplayer", args);
+
+#ifdef Q_WS_X11
+    QStringList args;
+    args << "-cache" << "4096" << "-fs" << url;
+    QProcess *player = new QProcess();
+    connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
+    player->start("/usr/bin/mplayer", args);
+#endif
 }
 
 void Controller::deleteVideo(const QString &path) {
