@@ -69,33 +69,22 @@ int main(int argc, char *argv[])
 
         return app.exec();
     }
-    else if (args.first() == ("--login")) {
-        /* Print accessToken to stdout for use by the widget*/
 
-        QNetworkAccessManager *manager = new QNetworkAccessManager();
-        yt.setNetworkAccessManager(manager);
-
-        QStringList account = ct.getDefaultAccountFromDB();
-        if (account.length() == 0) {
-            return 0;
-        }
-        QString username = account.first();
-        QString password = account.last();
-        QObject::connect(&yt, SIGNAL(accessTokenChanged()), &yt, SLOT(printAccessToken()));
-        QObject::connect(&yt, SIGNAL(tokenPrinted()), &app, SLOT(quit()));
-        yt.login(username, password);
-
-        app.exec();
-
-    }
     else if (args.first() == ("--play")) {
         /* Get the video URL and play the video */
 
-        QString playerUrl = args.last();
+        QString playerUrl = args.at(1);
+        QString quality = "High Quality";
+        if (args.length() > 2) {
+            if (args.at(2) == "m") {
+                quality = "Mobile";
+            }
+        }
         ct.getMediaPlayerFromDB();
         QObject::connect(&yt, SIGNAL(gotVideoUrl(QString)), &ct, SLOT(playVideo(QString)));
         QObject::connect(&yt, SIGNAL(videoUrlError()), &app, SLOT(quit()));
         QObject::connect(&ct, SIGNAL(playbackStarted()), &app, SLOT(quit()));
+        yt.setPlaybackQuality(quality);
         yt.getVideoUrl(playerUrl);
 
         app.exec();
