@@ -8,9 +8,13 @@
         <translation type="obsolete">cuteTube-QML - 0.5.1 - Suomennos: d-iivil</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.6.1</source>
-        <translation>cuteTube-QML - 0.6.1 - Suomennos: d-iivil</translation>
+        <translation type="obsolete">cuteTube-QML - 0.6.1 - Suomennos: d-iivil</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.6.3</source>
+        <translation>cuteTube-QML - 0.6.3 - Suomennos: d-iivil</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -171,42 +175,52 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="45"/>
+        <location filename="../../../controller.cpp" line="46"/>
         <source>English</source>
         <translation>Englanti</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="46"/>
+        <location filename="../../../controller.cpp" line="47"/>
         <source>German</source>
         <translation>Saksa</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="47"/>
+        <location filename="../../../controller.cpp" line="48"/>
         <source>Italian</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="48"/>
+        <location filename="../../../controller.cpp" line="49"/>
         <source>Finnish</source>
         <translation>Suomi</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="168"/>
+        <location filename="../../../controller.cpp" line="50"/>
+        <source>Dutch</source>
+        <translation>Alankomaiden</translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="51"/>
+        <source>Polish</source>
+        <translation>Puolalainen</translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="177"/>
         <source>Video deleted from device</source>
         <translation>Video poistettu laitteesta</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="171"/>
+        <location filename="../../../controller.cpp" line="180"/>
         <source>Unable to delete video</source>
         <translation>Videon poisto epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="175"/>
+        <location filename="../../../controller.cpp" line="184"/>
         <source>Video not found</source>
         <translation>Videota ei löytynyt</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="230"/>
+        <location filename="../../../controller.cpp" line="239"/>
         <source>Copied to clipboard</source>
         <translation>Kopioitu leikepöydälle</translation>
     </message>
@@ -549,27 +563,27 @@
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="19"/>
-        <location filename="../SettingsDialog.qml" line="38"/>
-        <location filename="../SettingsDialog.qml" line="71"/>
+        <location filename="../SettingsDialog.qml" line="39"/>
+        <location filename="../SettingsDialog.qml" line="72"/>
         <source>Automatically</source>
         <translation>Automaattisesti</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="19"/>
-        <location filename="../SettingsDialog.qml" line="41"/>
+        <location filename="../SettingsDialog.qml" line="42"/>
         <source>Manually</source>
         <translation>Manuaalisesti</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="45"/>
-        <location filename="../SettingsDialog.qml" line="77"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="78"/>
         <source>On</source>
         <translation>On</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="48"/>
+        <location filename="../SettingsDialog.qml" line="49"/>
         <source>Off</source>
         <translation>Pois</translation>
     </message>
@@ -589,8 +603,7 @@
         <translation>Pysty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
-        <location filename="../SettingsDialog.qml" line="128"/>
+        <location filename="../SettingsDialog.qml" line="129"/>
         <location filename="../SettingsDialog.qml" line="430"/>
         <source>Media Player</source>
         <translation>Mediasoitin</translation>
@@ -626,89 +639,99 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="37"/>
-        <location filename="../SettingsDialog.qml" line="72"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
+        <source>Dutch</source>
+        <translation>Alankomaiden</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="24"/>
+        <source>Polish</source>
+        <translation>Puolalainen</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <location filename="../SettingsDialog.qml" line="73"/>
         <source>Queued</source>
         <translation>Jonossa</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="75"/>
+        <location filename="../SettingsDialog.qml" line="76"/>
         <source>Paused</source>
         <translation>Pysäytetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="84"/>
+        <location filename="../SettingsDialog.qml" line="85"/>
         <source>Your settings have been saved</source>
         <translation>Asetukset tallennettu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="89"/>
-        <location filename="../SettingsDialog.qml" line="119"/>
+        <location filename="../SettingsDialog.qml" line="90"/>
+        <location filename="../SettingsDialog.qml" line="120"/>
         <source>Download Path</source>
         <translation>Latauspolku</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="91"/>
+        <location filename="../SettingsDialog.qml" line="92"/>
         <source>Download Location</source>
         <translation>Lataussijainti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="110"/>
+        <location filename="../SettingsDialog.qml" line="111"/>
         <location filename="../SettingsDialog.qml" line="320"/>
         <source>Playback Quality</source>
         <translation>Toistolaatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="114"/>
         <location filename="../SettingsDialog.qml" line="338"/>
         <source>Download Quality</source>
         <translation>Latauksen laatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="116"/>
+        <location filename="../SettingsDialog.qml" line="117"/>
         <location filename="../SettingsDialog.qml" line="356"/>
         <source>Start Downloads</source>
         <translation>Käynnistä lataukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="122"/>
+        <location filename="../SettingsDialog.qml" line="123"/>
         <location filename="../SettingsDialog.qml" line="261"/>
         <location filename="../SettingsDialog.qml" line="394"/>
         <source>Safe Search</source>
         <translation>Turvallinen Haku</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="125"/>
+        <location filename="../SettingsDialog.qml" line="126"/>
         <location filename="../SettingsDialog.qml" line="412"/>
         <source>Screen Orientation</source>
         <translation>Käyttöliittymän suunta</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="131"/>
+        <location filename="../SettingsDialog.qml" line="132"/>
         <location filename="../SettingsDialog.qml" line="285"/>
         <location filename="../SettingsDialog.qml" line="448"/>
         <source>Theme</source>
         <translation>Teema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="134"/>
+        <location filename="../SettingsDialog.qml" line="135"/>
         <location filename="../SettingsDialog.qml" line="294"/>
         <location filename="../SettingsDialog.qml" line="466"/>
         <source>Language</source>
         <translation>Kieli</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="143"/>
+        <location filename="../SettingsDialog.qml" line="144"/>
         <source>Your saved searches have been cleared</source>
         <translation>Tallennetut hakusanat on tyhjennetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="146"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Tietokantavirhe. Hakuja ei tyhjennetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="195"/>
+        <location filename="../SettingsDialog.qml" line="196"/>
         <source>Settings</source>
         <translation>Asetukset</translation>
     </message>
@@ -1197,7 +1220,7 @@
         <translation type="obsolete">Virhe: videon lataus epäonnistui</translation>
     </message>
     <message>
-        <location filename="../Widget.qml" line="271"/>
+        <location filename="../Widget.qml" line="287"/>
         <source>No videos found</source>
         <translation>Ei videoita</translation>
     </message>
@@ -1300,34 +1323,34 @@
         <translation>Olet kirjautunut YouTubeen tilillä: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="120"/>
-        <location filename="../../../youtube.cpp" line="226"/>
+        <location filename="../../../youtube.cpp" line="115"/>
+        <location filename="../../../youtube.cpp" line="221"/>
         <source>Error - Server repsonse is: </source>
         <translation>Virhe - Palvelin vastasi: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="170"/>
-        <location filename="../../../youtube.cpp" line="178"/>
+        <location filename="../../../youtube.cpp" line="165"/>
+        <location filename="../../../youtube.cpp" line="173"/>
         <source>Upload aborted</source>
         <translation>Lataus keskeytetty</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="185"/>
+        <location filename="../../../youtube.cpp" line="180"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Lataus keskeytyi. Kokeilen jatkaa...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="189"/>
+        <location filename="../../../youtube.cpp" line="184"/>
         <source>Upload failed</source>
         <translation>Lataus epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="195"/>
+        <location filename="../../../youtube.cpp" line="190"/>
         <source>Upload is completed</source>
         <translation>Lataus valmistui</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="387"/>
+        <location filename="../../../youtube.cpp" line="382"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Virhe: videon lataus epäonnistui</translation>
     </message>
@@ -1368,44 +1391,44 @@
         <translation>Video lisätty soittolistalle</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="159"/>
+        <location filename="../main.qml" line="160"/>
         <source>New playlist created</source>
         <translation>Uusi soittolista luotu</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="199"/>
+        <location filename="../main.qml" line="200"/>
         <source>Converting</source>
         <translation>Muunnetaan</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="208"/>
+        <location filename="../main.qml" line="209"/>
         <source>Conversion of &apos;</source>
         <translation>Muunto: </translation>
     </message>
     <message>
-        <location filename="../main.qml" line="208"/>
+        <location filename="../main.qml" line="209"/>
         <source>&apos; failed</source>
         <translation> epäonnistui</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="222"/>
-        <location filename="../main.qml" line="229"/>
-        <location filename="../main.qml" line="269"/>
+        <location filename="../main.qml" line="223"/>
+        <location filename="../main.qml" line="230"/>
+        <location filename="../main.qml" line="270"/>
         <source>Queued</source>
         <translation>Jonossa</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="237"/>
+        <location filename="../main.qml" line="238"/>
         <source>Paused</source>
         <translation>Keskeytetty</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="414"/>
+        <location filename="../main.qml" line="415"/>
         <source>Most Recent</source>
         <translation>Tuoreimmat</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="415"/>
+        <location filename="../main.qml" line="416"/>
         <source>Most Viewed</source>
         <translation>Katsotuimmat</translation>
     </message>
@@ -1413,9 +1436,8 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../scripts/mainscripts.js" line="19"/>
         <source>Media Player</source>
-        <translation>Mediasoitin</translation>
+        <translation type="obsolete">Mediasoitin</translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="119"/>
@@ -1497,9 +1519,8 @@
         <translation>Automaattinen</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="132"/>
         <source>Media Player</source>
-        <translation>Mediasoitin</translation>
+        <translation type="obsolete">Mediasoitin</translation>
     </message>
     <message>
         <location filename="../scripts/settings.js" line="133"/>
