@@ -62,12 +62,7 @@ void YouTube::setCurrentUser(const QString &user, const QString &pass) {
 
 void YouTube::setAccessToken(const QByteArray &token) {
     accessToken = token;
-    emit accessTokenChanged();
-}
-
-void YouTube::printAccessToken() {
-    printf(accessToken.toAscii());
-    emit tokenPrinted();
+    emit accessTokenChanged(accessToken);
 }
 
 void YouTube::uploadVideo(const QString &filename, const QString &title, const QString &description, const QString &tags, const QString &category, const bool &isPrivate) {
