@@ -28,7 +28,6 @@ public:
 
 public slots:
     void login(const QString &username, const QString &password);
-    void printAccessToken();
     void addToFavourites(const QString &videoId);
     void deleteFromFavourites(const QString &favouriteId);
     void addToPlaylist(const QString &videoId, const QString &playlistId);
@@ -77,8 +76,7 @@ signals:
     void videoUrlError();
     void alert(const QString &message);
     void currentUserChanged();
-    void accessTokenChanged();
-    void tokenPrinted();
+    void accessTokenChanged(const QString &token);
     void postSuccessful();
     void addedToFavourites();
     void addedToPlaylist();
